---
name: 📚 Documentation
about: Help with documentation improvements.
title: ''
labels: ''
assignees: ''
---

### Documentation request

Documentation is a high priority for outlines. If you would like to see something added to the documentation, please help us out by:

- Checking to see if the documentation does not already exist.
- Providing a detailed explanation of what you'd like to understand better.
- Highlighting any specific difficulties you ran into.

### Are you willing to open a PR?

Tell us whether you are willing to submit a PR for this yourself, we'd greatly appreciate it!

Thanks for contributing!
